@@ -9,10 +9,15 @@ from datetime import datetime
 
 
 class CsvFormatter(logging.Formatter):
+
+    def __init__(self, fmt, datefmt, delimiter=','):
+        super().__init__(fmt, datefmt)
+        self._delimiter = delimiter
+
     def format_msg(self, msg):
         ''' format the msg to csv string from list if list '''
         if isinstance(msg, list):
-            msg = ','.join(map(str, msg))
+            msg = self._delimiter.join(map(str, msg))
         return msg
 
     def format(self, record):
@@ -22,23 +27,23 @@ class CsvFormatter(logging.Formatter):
 
 
 class CsvRotatingFileHandler(RotatingFileHandler):
-    def __init__(self,
-                 fmt,
-                 datefmt,
-                 filename,
-                 max_size,
-                 max_files,
-                 header=None):
+
+    def __init__(
+            self,  #
+            fmt,
+            datefmt,
+            filename,
+            max_size,
+            max_files,
+            header=None,
+            delimiter=','):
         # Format header string if needed
-        self._header = header and CsvFormatter(fmt, datefmt).format_msg(header)
+        self._header = header and CsvFormatter(fmt, datefmt, delimiter).format_msg(header)
         # check if file exists
         self.file_pre_exists = path.exists(filename)
         # call parent file handler __init__
-        RotatingFileHandler.__init__(self,
-                                     filename,
-                                     maxBytes=max_size,
-                                     backupCount=max_files)
-        self.formatter = CsvFormatter(fmt, datefmt)
+        RotatingFileHandler.__init__(self, filename, maxBytes=max_size, backupCount=max_files)
+        self.formatter = CsvFormatter(fmt, datefmt, delimiter)
         # Write the header if delay is False and a file stream was created.
         if self.stream is not None and not self.file_pre_exists:
             self.stream.write('%s\n' % self._header)
@@ -46,14 +51,15 @@ class CsvRotatingFileHandler(RotatingFileHandler):
     def rotation_filename(self, default_name):
         ''' make log files counter before the .csv extension '''
         s = default_name.rsplit('.', 2)
-        return '{}_{:0{}d}.csv'.format(s[0], int(s[-1]),
-                                       self.backupCount // 10 + 1)
+        return '{}_{:0{}d}.csv'.format(s[0], int(s[-1]), self.backupCount // 10 + 1)
 
     def doRollover(self):
         ''' prepend header string to each log file '''
         RotatingFileHandler.doRollover(self)
         if self._header is None:
             return
+        # temporarily overwrite format function with a straight pass-through lambda function
+        # handle header without formatting, then reset format function to what it was
         f = self.formatter.format
         self.formatter.format = lambda x: x
         self.handle(self._header)
@@ -61,8 +67,10 @@ class CsvRotatingFileHandler(RotatingFileHandler):
 
 
 class CsvLogger(logging.Logger):
+
     def __init__(self,
                  filename: str,
+                 delimiter=',',
                  level=logging.INFO,
                  add_level_names=[],
                  add_level_nums=None,
@@ -75,6 +83,7 @@ class CsvLogger(logging.Logger):
 
         Args:
             filename (string): main log file name or path. if path, will create subfolders as needed
+            delimiter (str, optional): delimiter to use in the files. Defaults to ','.
             level (logging level | str | int, optional): logging level for logs. Defaults to logging.INFO.
             add_level_names (list[str], optional): adds additional logging levels at the highest level for custom log tagging
             add_level_nums (list[int], optional): assigns specific nums to add_level_names (default nums if not provided: 100,99,98..)
@@ -85,9 +94,13 @@ class CsvLogger(logging.Logger):
             header (list[str], optional): header to prepend to csv files. Defaults to None
         """
         self.filename = filename
+        self.delimiter = delimiter
+        # if default fmt is still set but delimiter is not comma, replace with delimiter
+        if fmt == '%(asctime)s,%(message)s' and delimiter != ',':
+            fmt = f'%(asctime)s{delimiter}%(message)s'
         self.datefmt = datefmt
         if header and isinstance(header, str):
-            header = header.split(',')
+            header = header.split(delimiter)
         self.header = header
 
         # make log file directories
@@ -95,14 +108,11 @@ class CsvLogger(logging.Logger):
             makedirs(path.dirname(filename), exist_ok=True)
         # init logger and add handler
         logging.Logger.__init__(self, filename.rsplit('.', 1)[0], level)
-        add_level_nums = add_level_nums or [
-            100 - i for i in range(len(add_level_names))
-        ]
+        add_level_nums = add_level_nums or [100 - i for i in range(len(add_level_names))]
         for level_num, level_name in zip(add_level_nums, add_level_names):
             self.addLoggingLevel(level_name, level_num, level_name)
 
-        handler = CsvRotatingFileHandler(fmt, datefmt, filename, max_size,
-                                         max_files, header)
+        handler = CsvRotatingFileHandler(fmt, datefmt, filename, max_size, max_files, header, delimiter)
         self.addHandler(handler)
 
     def addLoggingLevel(self, levelName, levelNum, methodName=None):
@@ -136,14 +146,11 @@ class CsvLogger(logging.Logger):
             methodName = levelName.lower()
 
         if hasattr(logging, levelName):
-            raise AttributeError(
-                '{} already defined in logging module'.format(levelName))
+            raise AttributeError('{} already defined in logging module'.format(levelName))
         if hasattr(logging, methodName):
-            raise AttributeError(
-                '{} already defined in logging module'.format(methodName))
+            raise AttributeError('{} already defined in logging module'.format(methodName))
         if hasattr(logging.getLoggerClass(), methodName):
-            raise AttributeError(
-                '{} already defined in logger class'.format(methodName))
+            raise AttributeError('{} already defined in logger class'.format(methodName))
 
         # This method was inspired by the answers to Stack Overflow post
         # http://stackoverflow.com/q/2183233/2988730, especially
@@ -174,7 +181,7 @@ class CsvLogger(logging.Logger):
         # read each log file and create list of csv logs
         for logfile in logfiles:
             with open(logfile, newline='') as csvfile:
-                csvreader = csv.reader(csvfile, delimiter=',', quotechar='|')
+                csvreader = csv.reader(csvfile, delimiter=self.delimiter, quotechar='|')
                 for row in csvreader:
                     if row != self.header:
                         if evaluate:
@@ -185,8 +192,7 @@ class CsvLogger(logging.Logger):
                                     new_row.append(eval(x))
                                 except:
                                     try:
-                                        new_row.append(
-                                            datetime.strptime(x, self.datefmt))
+                                        new_row.append(datetime.strptime(x, self.datefmt))
                                     except:
                                         new_row.append(x)
                             row = new_row
